<template>
  <ProDialog title="批改信息" v-model="innerVisible" width="1200px" destroy-on-close>
    <ProDialogTableWrapper :height="400">
      <ProTableV2
        :table-data="proTableProps.tableData"
        :columns="column"
        :show-operation-column="false"
      >
      </ProTableV2>
    </ProDialogTableWrapper>
  </ProDialog>
</template>

<script setup lang="ts">
import { ProDialog, ProTableV2, ProDialogTableWrapper, useTable } from '@bole-core/components';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { OrderInputType } from '@bole-core/core';

defineOptions({
  name: 'BatchChangeRecordDetailDialog',
});

type Props = {
  modelValue: boolean;
  form?: {
    id: string;
  };
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'onCancel'): void;
}>();

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'name',
    name: '批改类型',
    width: 120,
  },
  {
    id: '2',
    enCode: 'name',
    name: '姓名',
    width: 120,
  },
  {
    id: '3',
    enCode: 'name',
    name: '身份证号',
    width: 120,
  },
  {
    id: '4',
    enCode: 'name',
    name: '雇员工种',
    width: 120,
  },
  {
    id: '5',
    enCode: 'name',
    name: '性别',
    width: 120,
  },
  {
    id: '6',
    enCode: 'name',
    name: '年龄',
    width: 120,
  },
  {
    id: '7',
    enCode: 'name',
    name: '出生日期',
    width: 120,
  },
  {
    id: '8',
    enCode: 'name',
    name: '电话号码',
    width: 120,
  },
  {
    id: '9',
    enCode: 'name',
    name: '修改内容',
    width: 120,
  },
];

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

watch(
  () => props.modelValue,
  (val) => {
    if (val) {
      getBatchRefundInfoDetail();
    }
  },
  {
    immediate: true,
  }
);

const {
  getDataSource: getBatchRefundInfoDetail,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.QueryInsuranceOrderPageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        condition: extraParamState.keyWord,
        // insurePolicyOperateHistoryId: id,
      };
      let res = await insuranceOrderServices.getInsuranceOrderPage(params);
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyWord: '',
      orderInput: [{ property: 'id', order: OrderInputType.Asc }],
    },
    columnsRenderProps: {},
  }
);
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
